/****************************************************************************
** Meta object code from reading C++ file 'kmediaplayeradaptor_p.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmediaplayer-5.43.0/src/kmediaplayeradaptor_p.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'kmediaplayeradaptor_p.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMediaPlayerAdaptor_t {
    QByteArrayData data[19];
    char stringdata0[1115];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMediaPlayerAdaptor_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMediaPlayerAdaptor_t qt_meta_stringdata_KMediaPlayerAdaptor = {
    {
QT_MOC_LITERAL(0, 0, 19), // "KMediaPlayerAdaptor"
QT_MOC_LITERAL(1, 20, 15), // "D-Bus Interface"
QT_MOC_LITERAL(2, 36, 20), // "org.kde.KMediaPlayer"
QT_MOC_LITERAL(3, 57, 19), // "D-Bus Introspection"
QT_MOC_LITERAL(4, 77, 948), // "  <interface name=\"org.kde.K..."
QT_MOC_LITERAL(5, 954, 7), // "openUrl"
QT_MOC_LITERAL(6, 962, 0), // ""
QT_MOC_LITERAL(7, 963, 4), // "file"
QT_MOC_LITERAL(8, 968, 5), // "pause"
QT_MOC_LITERAL(9, 974, 4), // "play"
QT_MOC_LITERAL(10, 979, 4), // "seek"
QT_MOC_LITERAL(11, 984, 4), // "msec"
QT_MOC_LITERAL(12, 989, 4), // "stop"
QT_MOC_LITERAL(13, 994, 9), // "hasLength"
QT_MOC_LITERAL(14, 1004, 6), // "length"
QT_MOC_LITERAL(15, 1011, 7), // "looping"
QT_MOC_LITERAL(16, 1019, 8), // "position"
QT_MOC_LITERAL(17, 1028, 8), // "seekable"
QT_MOC_LITERAL(18, 1037, 5) // "state"

    },
    "KMediaPlayerAdaptor\0D-Bus Interface\0"
    "org.kde.KMediaPlayer\0D-Bus Introspection\0"
    "  <interface name=\"org.kde.KMediaPlayer\" >    <method name=\"openUrl"
    "\" >      <arg direction=\"in\" type=\"s\" name=\"file\" />      <arg "
    "direction=\"out\" type=\"b\" />    </method>    <method name=\"pause\""
    " />    <method name=\"play\" />    <method name=\"stop\" />    <method"
    " name=\"seek\" >      <arg direction=\"in\" type=\"x\" name=\"msec\" /"
    ">    </method>    <property access=\"read\" type=\"b\" name=\"seekable"
    "\" >      <annotation value=\"isSeekable\" name=\"com.trolltech.QtDBus"
    ".propertyGetter\" />    </property>    <property access=\"read\" type="
    "\"x\" name=\"position\" />    <property access=\"read\" type=\"b\" nam"
    "e=\"hasLength\" />    <property access=\"read\" type=\"x\" name=\"leng"
    "th\" />    <property access=\"readwrite\" type=\"b\" name=\"looping\" "
    ">      <annotation value=\"isLooping\" name=\"com.trolltech.QtDBus.pro"
    "pertyGetter\" />    </property>    <property access=\"readwrite\" type"
    "=\"i\" name=\"state\" />  </interface>\0"
    "openUrl\0\0file\0pause\0play\0seek\0msec\0"
    "stop\0hasLength\0length\0looping\0position\0"
    "seekable\0state"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMediaPlayerAdaptor[] = {

 // content:
       7,       // revision
       0,       // classname
       2,   14, // classinfo
       5,   18, // methods
       6,   52, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // classinfo: key, value
       1,    2,
       3,    4,

 // slots: name, argc, parameters, tag, flags
       5,    1,   43,    6, 0x0a /* Public */,
       8,    0,   46,    6, 0x0a /* Public */,
       9,    0,   47,    6, 0x0a /* Public */,
      10,    1,   48,    6, 0x0a /* Public */,
      12,    0,   51,    6, 0x0a /* Public */,

 // slots: parameters
    QMetaType::Bool, QMetaType::QString,    7,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   11,
    QMetaType::Void,

 // properties: name, type, flags
      13, QMetaType::Bool, 0x00095001,
      14, QMetaType::LongLong, 0x00095001,
      15, QMetaType::Bool, 0x00095103,
      16, QMetaType::LongLong, 0x00095001,
      17, QMetaType::Bool, 0x00095001,
      18, QMetaType::Int, 0x00095103,

       0        // eod
};

void KMediaPlayerAdaptor::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        KMediaPlayerAdaptor *_t = static_cast<KMediaPlayerAdaptor *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: { bool _r = _t->openUrl((*reinterpret_cast< const QString(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 1: _t->pause(); break;
        case 2: _t->play(); break;
        case 3: _t->seek((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 4: _t->stop(); break;
        default: ;
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        KMediaPlayerAdaptor *_t = static_cast<KMediaPlayerAdaptor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->hasLength(); break;
        case 1: *reinterpret_cast< qlonglong*>(_v) = _t->length(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isLooping(); break;
        case 3: *reinterpret_cast< qlonglong*>(_v) = _t->position(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isSeekable(); break;
        case 5: *reinterpret_cast< int*>(_v) = _t->state(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        KMediaPlayerAdaptor *_t = static_cast<KMediaPlayerAdaptor *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setLooping(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setState(*reinterpret_cast< int*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KMediaPlayerAdaptor::staticMetaObject = {
    { &QDBusAbstractAdaptor::staticMetaObject, qt_meta_stringdata_KMediaPlayerAdaptor.data,
      qt_meta_data_KMediaPlayerAdaptor,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMediaPlayerAdaptor::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMediaPlayerAdaptor::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMediaPlayerAdaptor.stringdata0))
        return static_cast<void*>(this);
    return QDBusAbstractAdaptor::qt_metacast(_clname);
}

int KMediaPlayerAdaptor::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDBusAbstractAdaptor::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 5)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 5;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 5)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 5;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
