/****************************************************************************
** Meta object code from reading C++ file 'view.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmediaplayer-5.43.0/src/view.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'view.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMediaPlayer__View_t {
    QByteArrayData data[19];
    char stringdata0[187];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMediaPlayer__View_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMediaPlayer__View_t qt_meta_stringdata_KMediaPlayer__View = {
    {
QT_MOC_LITERAL(0, 0, 18), // "KMediaPlayer::View"
QT_MOC_LITERAL(1, 19, 14), // "buttonsChanged"
QT_MOC_LITERAL(2, 34, 0), // ""
QT_MOC_LITERAL(3, 35, 27), // "KMediaPlayer::View::Buttons"
QT_MOC_LITERAL(4, 63, 7), // "buttons"
QT_MOC_LITERAL(5, 71, 10), // "setButtons"
QT_MOC_LITERAL(6, 82, 7), // "Buttons"
QT_MOC_LITERAL(7, 90, 6), // "button"
QT_MOC_LITERAL(8, 97, 6), // "Button"
QT_MOC_LITERAL(9, 104, 10), // "showButton"
QT_MOC_LITERAL(10, 115, 10), // "hideButton"
QT_MOC_LITERAL(11, 126, 12), // "toggleButton"
QT_MOC_LITERAL(12, 139, 11), // "videoWidget"
QT_MOC_LITERAL(13, 151, 8), // "QWidget*"
QT_MOC_LITERAL(14, 160, 4), // "Play"
QT_MOC_LITERAL(15, 165, 4), // "Stop"
QT_MOC_LITERAL(16, 170, 5), // "Pause"
QT_MOC_LITERAL(17, 176, 6), // "Seeker"
QT_MOC_LITERAL(18, 183, 3) // "All"

    },
    "KMediaPlayer::View\0buttonsChanged\0\0"
    "KMediaPlayer::View::Buttons\0buttons\0"
    "setButtons\0Buttons\0button\0Button\0"
    "showButton\0hideButton\0toggleButton\0"
    "videoWidget\0QWidget*\0Play\0Stop\0Pause\0"
    "Seeker\0All"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMediaPlayer__View[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       6,   14, // methods
       2,   62, // properties
       2,   70, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   44,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       5,    1,   47,    2, 0x0a /* Public */,
       7,    1,   50,    2, 0x0a /* Public */,
       9,    1,   53,    2, 0x0a /* Public */,
      10,    1,   56,    2, 0x0a /* Public */,
      11,    1,   59,    2, 0x0a /* Public */,

 // signals: parameters
    QMetaType::Void, 0x80000000 | 3,    4,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 6,    4,
    QMetaType::Bool, 0x80000000 | 8,    7,
    QMetaType::Void, 0x80000000 | 8,    7,
    QMetaType::Void, 0x80000000 | 8,    7,
    QMetaType::Void, 0x80000000 | 8,    7,

 // properties: name, type, flags
       4, 0x80000000 | 6, 0x0049510b,
      12, 0x80000000 | 13, 0x00095009,

 // properties: notify_signal_id
       0,
       0,

 // enums: name, flags, count, data
       8, 0x1,    5,   78,
       6, 0x1,    5,   88,

 // enum data: key, value
      14, uint(KMediaPlayer::View::Play),
      15, uint(KMediaPlayer::View::Stop),
      16, uint(KMediaPlayer::View::Pause),
      17, uint(KMediaPlayer::View::Seeker),
      18, uint(KMediaPlayer::View::All),
      14, uint(KMediaPlayer::View::Play),
      15, uint(KMediaPlayer::View::Stop),
      16, uint(KMediaPlayer::View::Pause),
      17, uint(KMediaPlayer::View::Seeker),
      18, uint(KMediaPlayer::View::All),

       0        // eod
};

void KMediaPlayer::View::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->buttonsChanged((*reinterpret_cast< KMediaPlayer::View::Buttons(*)>(_a[1]))); break;
        case 1: _t->setButtons((*reinterpret_cast< Buttons(*)>(_a[1]))); break;
        case 2: { bool _r = _t->button((*reinterpret_cast< Button(*)>(_a[1])));
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 3: _t->showButton((*reinterpret_cast< Button(*)>(_a[1]))); break;
        case 4: _t->hideButton((*reinterpret_cast< Button(*)>(_a[1]))); break;
        case 5: _t->toggleButton((*reinterpret_cast< Button(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 0:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KMediaPlayer::View::Buttons >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (View::*_t)(KMediaPlayer::View::Buttons );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&View::buttonsChanged)) {
                *result = 0;
                return;
            }
        }
    } else if (_c == QMetaObject::RegisterPropertyMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< QWidget* >(); break;
        }
    }

#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast<int*>(_v) = QFlag(_t->buttons()); break;
        case 1: *reinterpret_cast< QWidget**>(_v) = _t->videoWidget(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        View *_t = static_cast<View *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: _t->setButtons(QFlag(*reinterpret_cast<int*>(_v))); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KMediaPlayer::View::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_KMediaPlayer__View.data,
      qt_meta_data_KMediaPlayer__View,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMediaPlayer::View::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMediaPlayer::View::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMediaPlayer__View.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int KMediaPlayer::View::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 6)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 2;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 2;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KMediaPlayer::View::buttonsChanged(KMediaPlayer::View::Buttons _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
