/****************************************************************************
** Meta object code from reading C++ file 'player.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../src/kmediaplayer-5.43.0/src/player.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'player.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_KMediaPlayer__Player_t {
    QByteArrayData data[26];
    char stringdata0[223];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_KMediaPlayer__Player_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_KMediaPlayer__Player_t qt_meta_stringdata_KMediaPlayer__Player = {
    {
QT_MOC_LITERAL(0, 0, 20), // "KMediaPlayer::Player"
QT_MOC_LITERAL(1, 21, 14), // "loopingChanged"
QT_MOC_LITERAL(2, 36, 0), // ""
QT_MOC_LITERAL(3, 37, 9), // "isLooping"
QT_MOC_LITERAL(4, 47, 12), // "stateChanged"
QT_MOC_LITERAL(5, 60, 27), // "KMediaPlayer::Player::State"
QT_MOC_LITERAL(6, 88, 8), // "newState"
QT_MOC_LITERAL(7, 97, 5), // "pause"
QT_MOC_LITERAL(8, 103, 4), // "play"
QT_MOC_LITERAL(9, 108, 4), // "stop"
QT_MOC_LITERAL(10, 113, 4), // "seek"
QT_MOC_LITERAL(11, 118, 4), // "msec"
QT_MOC_LITERAL(12, 123, 10), // "setLooping"
QT_MOC_LITERAL(13, 134, 2), // "on"
QT_MOC_LITERAL(14, 137, 8), // "setState"
QT_MOC_LITERAL(15, 146, 5), // "State"
QT_MOC_LITERAL(16, 152, 5), // "state"
QT_MOC_LITERAL(17, 158, 9), // "hasLength"
QT_MOC_LITERAL(18, 168, 6), // "length"
QT_MOC_LITERAL(19, 175, 7), // "looping"
QT_MOC_LITERAL(20, 183, 8), // "position"
QT_MOC_LITERAL(21, 192, 8), // "seekable"
QT_MOC_LITERAL(22, 201, 5), // "Empty"
QT_MOC_LITERAL(23, 207, 4), // "Stop"
QT_MOC_LITERAL(24, 212, 5), // "Pause"
QT_MOC_LITERAL(25, 218, 4) // "Play"

    },
    "KMediaPlayer::Player\0loopingChanged\0"
    "\0isLooping\0stateChanged\0"
    "KMediaPlayer::Player::State\0newState\0"
    "pause\0play\0stop\0seek\0msec\0setLooping\0"
    "on\0setState\0State\0state\0hasLength\0"
    "length\0looping\0position\0seekable\0Empty\0"
    "Stop\0Pause\0Play"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_KMediaPlayer__Player[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
       8,   14, // methods
       6,   72, // properties
       1,   96, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    1,   54,    2, 0x06 /* Public */,
       4,    1,   57,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       7,    0,   60,    2, 0x0a /* Public */,
       8,    0,   61,    2, 0x0a /* Public */,
       9,    0,   62,    2, 0x0a /* Public */,
      10,    1,   63,    2, 0x0a /* Public */,
      12,    1,   66,    2, 0x0a /* Public */,
      14,    1,   69,    2, 0x09 /* Protected */,

 // signals: parameters
    QMetaType::Void, QMetaType::Bool,    3,
    QMetaType::Void, 0x80000000 | 5,    6,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::LongLong,   11,
    QMetaType::Void, QMetaType::Bool,   13,
    QMetaType::Void, 0x80000000 | 15,   16,

 // properties: name, type, flags
      17, QMetaType::Bool, 0x00095001,
      18, QMetaType::LongLong, 0x00095001,
      19, QMetaType::Bool, 0x00095103,
      20, QMetaType::LongLong, 0x00095001,
      21, QMetaType::Bool, 0x00095001,
      16, 0x80000000 | 15, 0x0049510b,

 // properties: notify_signal_id
       0,
       0,
       0,
       0,
       0,
       1,

 // enums: name, flags, count, data
      15, 0x0,    4,  100,

 // enum data: key, value
      22, uint(KMediaPlayer::Player::Empty),
      23, uint(KMediaPlayer::Player::Stop),
      24, uint(KMediaPlayer::Player::Pause),
      25, uint(KMediaPlayer::Player::Play),

       0        // eod
};

void KMediaPlayer::Player::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        Player *_t = static_cast<Player *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->loopingChanged((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 1: _t->stateChanged((*reinterpret_cast< KMediaPlayer::Player::State(*)>(_a[1]))); break;
        case 2: _t->pause(); break;
        case 3: _t->play(); break;
        case 4: _t->stop(); break;
        case 5: _t->seek((*reinterpret_cast< qlonglong(*)>(_a[1]))); break;
        case 6: _t->setLooping((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->setState((*reinterpret_cast< State(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 1:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< KMediaPlayer::Player::State >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (Player::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Player::loopingChanged)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (Player::*_t)(KMediaPlayer::Player::State );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&Player::stateChanged)) {
                *result = 1;
                return;
            }
        }
    }
#ifndef QT_NO_PROPERTIES
    else if (_c == QMetaObject::ReadProperty) {
        Player *_t = static_cast<Player *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 0: *reinterpret_cast< bool*>(_v) = _t->hasLength(); break;
        case 1: *reinterpret_cast< qlonglong*>(_v) = _t->length(); break;
        case 2: *reinterpret_cast< bool*>(_v) = _t->isLooping(); break;
        case 3: *reinterpret_cast< qlonglong*>(_v) = _t->position(); break;
        case 4: *reinterpret_cast< bool*>(_v) = _t->isSeekable(); break;
        case 5: *reinterpret_cast< State*>(_v) = _t->state(); break;
        default: break;
        }
    } else if (_c == QMetaObject::WriteProperty) {
        Player *_t = static_cast<Player *>(_o);
        Q_UNUSED(_t)
        void *_v = _a[0];
        switch (_id) {
        case 2: _t->setLooping(*reinterpret_cast< bool*>(_v)); break;
        case 5: _t->setState(*reinterpret_cast< State*>(_v)); break;
        default: break;
        }
    } else if (_c == QMetaObject::ResetProperty) {
    }
#endif // QT_NO_PROPERTIES
}

const QMetaObject KMediaPlayer::Player::staticMetaObject = {
    { &KParts::ReadOnlyPart::staticMetaObject, qt_meta_stringdata_KMediaPlayer__Player.data,
      qt_meta_data_KMediaPlayer__Player,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *KMediaPlayer::Player::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *KMediaPlayer::Player::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_KMediaPlayer__Player.stringdata0))
        return static_cast<void*>(this);
    return KParts::ReadOnlyPart::qt_metacast(_clname);
}

int KMediaPlayer::Player::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = KParts::ReadOnlyPart::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 8)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 8;
    }
#ifndef QT_NO_PROPERTIES
   else if (_c == QMetaObject::ReadProperty || _c == QMetaObject::WriteProperty
            || _c == QMetaObject::ResetProperty || _c == QMetaObject::RegisterPropertyMetaType) {
        qt_static_metacall(this, _c, _id, _a);
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyDesignable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyScriptable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyStored) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyEditable) {
        _id -= 6;
    } else if (_c == QMetaObject::QueryPropertyUser) {
        _id -= 6;
    }
#endif // QT_NO_PROPERTIES
    return _id;
}

// SIGNAL 0
void KMediaPlayer::Player::loopingChanged(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void KMediaPlayer::Player::stateChanged(KMediaPlayer::Player::State _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
